% Compute the mass matrices of the individual gcells.
% Return an array of them so they may be assembled.
%   Call as:
%     ems = mass(feb, geom, w);
%   geom=geometry field
%   w=displacement field
%
function ems = mass (self, geom, w)
    gcells = get(self.feblock,'gcells');
    ngcells = length(gcells);
    nfens = get(gcells(1),'nfens');
    dim = get(geom,'dim');
    ems(1:ngcells) = deal(elemat);% Pre-allocate the element matrices
    integration_rule = get(self.feblock, 'integration_rule');
    pc = get(integration_rule, 'param_coords');
    weights  = get(integration_rule, 'weights');
    mat = get(self.feblock, 'mater');
    rho = get(mat, 'rho');
    Nexp = zeros(dim,dim*nfens);
    % Now loop over all gcells in the block
    for i=1:ngcells
        npts_per_gcell = get(integration_rule, 'npts');
        conn = get(gcells(i), 'conn'); % connectivity
        x = gather(geom, conn, 'values', 'noreshape'); % coordinates of nodes
        M = zeros(dim*nfens); % element stiffness matrix
        % Loop over all integration points
        for j=1:npts_per_gcell
            Nder = Ndermat_param (gcells(i), pc(j,:));
            [Nspatialder,detJ] = Ndermat_spatial (gcells(i), Nder, xl);
            N = Nmat (gcells(i), pc(j,1:end));
            for l = 1:nfens; Nexp(1:dim,(l-1)*dim+1:(l)*dim)=eye(dim,dim)*N(l); end;
            M = M + Nexp'*Nexp * detJ * rho * area(gcells(i), pc(j,:)) * weights(j);
        end
        ems(i) = set(ems(i), 'mat', M);
        ems(i) = set(ems(i), 'eqnums', gather(w, conn, 'eqnums'));
    end
    return;
end