% Constructor of the finite element block class.
%    This class implements the linear steady-diffusion operations.
%
% Always takes either zero or one argument.  For no arguments, the default
% object is created.  For one argument, the argument may be either an
% object of the same type, in which case the copy is created; or, it may be
% a struct with the following fields representing options.
% Options: those recognized by feblock
%
function retobj = feblock_defor_ss (varargin)
    class_name='feblock_diffusion';
    if (nargin == 0)
        parent = feblock;
        self.surface_transfer = 0;
        self.matstates= [];
        retobj = class(self,class_name,parent);
        return;
    elseif (nargin == 1)
        arg = varargin{1};
        if strcmp(class(arg),class_name) % copy constructor.
            retobj = arg;
            return;
        else
            options =varargin{1};
            parent = feblock(varargin{:});
            surface_transfer =0;
            if isfield(options,'surface_transfer')
                surface_transfer= options.surface_transfer;
            end
            self.surface_transfer = surface_transfer;
            self.matstates= [];
            retobj = class(self,class_name,parent);
            return;
        end
    else
        error('Illegal arguments!');
    end
    return;
end