% Compute the element load vectors corresponding to nonzero
% essential boundary
% conditions (prescribed temperature).
% Return an array of them so they may be assembled.
%    Call as
% evs = nz_ebc_loads_conductivity(feb, geom, temp)
%     geom=geometry field
%     temp=temperature field
%
function evs = nz_ebc_loads_conductivity(self, geom, temp)
    gcells = get(self.feblock,'gcells');
    ngcells = length(gcells);
    nfens = get(gcells(1),'nfens');
    dim = get(geom,'dim');
    % Pre-allocate the element matrices
    evs(1:ngcells) = deal(elevec);
    % Integration rule
    integration_rule = get(self.feblock, 'integration_rule');
    pc = get(integration_rule, 'param_coords');
    w  = get(integration_rule, 'weights');
    npts_per_gcell = get(integration_rule, 'npts');
    % Material
    mat = get(self.feblock, 'mater');
    kappa = get(mat,'conductivity');
    % Now loop over all gcells in the block
    for i=1:ngcells
        conn = get(gcells(i), 'conn'); % connectivity
        pT = gather(temp, conn, 'prescribed_values');
        if norm (pT) ~= 0
            x = gather(geom, conn, 'values', 'noreshape');
            Ke = zeros(nfens); % element matrix
            % Loop over all integration points
            for j=1:npts_per_gcell
                Nder = Ndermat_param (gcells(i), pc(j,:));
                Rm=material_directions(self,...
                    map_to_xyz(gcells(i), pc(j,:),x),x'*Nder);
                [Nspder,detJ]=Ndermat_spatial(gcells(i),Nder,x);
                Ke=Ke + Nspder*Rm*kappa*Rm'*Nspder' *detJ*w(j);
            end
            evs(i) = set(evs(i), 'vec', -Ke*pT);
            evs(i) = set(evs(i), 'eqnums', ...
                gather(temp, conn, 'eqnums'));
        end
    end
    return;
end
