% Constructor
% class represents a two-node Rod geometric cell, which encloses some part
% of the computational domain.
% Always takes either zero or one argument.  For no arguments, the default
% object is created.  For one argument, the argument may be either an
% object of the same type, in which case the copy is created; or, it may be
% a struct with the following fields representing options.
% Options: same as gcell_1_manifold.
% and area = cross-sectional area of the rod (default is 1.0)
%   Example: gcell_L2(struct ('id',13,'conn',[21 3], 'area',4.5))  creates a cell
%      that connects nodes 21 3, hands cross-sectional area of 4.5 units, and gives it the `name' 13.
%
function retobj = gcell_L2 (varargin)
    class_name='gcell_L2';
    nfens=2;
    if (nargin == 0)
        options.nfens=nfens;
        parent=gcell_1_manifold(options);
        retobj = class(struct([]),class_name, parent);
    elseif (nargin == 1)
        arg = varargin{1};
        if strcmp(class(arg),class_name) % copy constructor.
            retobj = arg;
            return;
        else
            options=varargin{1}; options.nfens=nfens;
            parent=gcell_1_manifold(options);
            retobj = class(struct([]),class_name, parent);
            return;
        end
    else
        error('Illegal arguments!');
    end
    return;
end