% Constructor.
% This class represents deformable materials, linear elastic, isotropic,
% for biaxial strain/stress states.
% Always takes either zero or one argument.  For no arguments, the default
% object is created.  For one argument, the argument may be either an
% object of the same type, in which case the copy is created; or, it may be
% a struct with the following fields representing options.
% Options:
% required fields
%     E=Young's modulus
%     nu=Poisson ratio
%     type = type of stress state, 'stress' (for plane stress), or 'strain'
%          (for plane strain).
%
function retobj = mater_defor_ss_linel_iso_biax (varargin)
    class_name='mater_defor_ss_linel_iso_biax';
    if (nargin == 0)
        parent=mater_defor;
        self.E = 1.0;
        self.nu = 0.0;
        self.type ='strain';
        retobj = class(self,class_name, parent);
        return;
    elseif (nargin == 1)
        arg = varargin{1};
        if strcmp(class(arg),class_name) % copy constructor.
            retobj = arg;
            return;
        else
            options =varargin{1};
            parent=mater_defor(options);
            self.E = options.E;
            self.nu = options.nu;
            if (self.nu < 0)
                error('Negative Poisson ratio!');
            elseif (self.nu >= 0.5)
                error('Incompressible material!');
            end
            self.type = options.type;
            switch self.type
                case 'strain'
                case 'stress'
                otherwise
                    error (['Unknown type: ' type]);
            end
            retobj = class(self,class_name, parent);
            return;
        end
    else
        error('Illegal arguments!');
    end
    return;
end